#!/usr/bin/perl

use strict;
use CGI;
use FDN::Common::Logger;
use FDN::Web::Forms;
use FDN::Web::Session;
use FDN::Adsl::Basic;
use FDN::Adsl::Utils;

my $form = form_read('adsl/adhs/adh.cfg','in');
my $cgi = new CGI;
my $vars = $cgi->Vars;

if ( $vars->{'do'} ne 'yes' ) {
	eject_page(affiche_form($form,$vars));
	exit(0);
}

if ( ! check_transition($form,$vars) ) {
	eject_page(affiche_form($form,$vars));
	exit(0);
}

my $use_rad;
my $use_tel;
my $use_adh;

if ( defined $vars->{'telephone'} &&
     $vars->{'telephone'} &&
     defined $vars->{'dplnum'} &&
     $vars->{'dplnum'} ) {
	$use_tel = 1;
	info "Authentification par telephone";
}

if ( defined $vars->{'radlogin'} &&
     defined $vars->{'radpsswd'} &&
     $vars->{'radlogin'} &&
     $vars->{'radpsswd'} ) {
	$use_rad = 1;
	info "Authentification par login radius";
}

if ( defined $vars->{'adhlogin'} &&
     defined $vars->{'adhpasswd'} &&
     $vars->{'adhlogin'} &&
     $vars->{'adhpasswd'} ) {
	$use_adh = 1;
	info "Authentification par adhaccess";
}

my $err = "<div class=\"error\"><p>Erreur d'authentification</p></div>";
my $page;
if ( ! $use_rad && ! $use_tel && ! $use_adh ) {
	info "Aucune methode d'authentification choisie";
	$page = affiche_form($form,$vars);
	$page .= $err;
	eject_page($page);
	exit(0);
}

my $logok;
my $cid;

if ( $use_tel ) {
	my $ligne = ligne_par_tel($vars->{'telephone'});
	if ( ! defined $ligne ) {
		info "Numero de telephone inconnu";
		goto BAD;
	}
	my $dpl = deploiement_par_ligne_id($ligne->{'LIGNE_ID'});
	if ( ! defined $dpl ) {
		info "Numero de commande inconnu";
		goto BAD;
	}
	if ( $dpl->{'DEPLOIEMENT_NUM'} ne $vars->{'dplnum'} ) {
		info "Numero de telephone et de commande ne correspondent pas";
		goto BAD;
	}
	$logok = 1;
	$cid = $ligne->{'CLIENT_ID'};
} elsif ( $use_rad) {
	my $ru = raduser_par_login($vars->{'radlogin'});
	if ( ! defined $ru ) {
		info "Login radius inconnu";
		goto BAD;
	}
	my @attrs = uattr_par_raduser_id_type($ru->{'RADUSER_ID'},'check');
	for my $attr ( @attrs ) {
		next if ( ! defined $attr );
		debug "Vu attribut ".$attr->{'UATTR_ATTR'}." valeur ".$attr->{'UATTR_VALUE'};
		if ( $attr->{'UATTR_ATTR'} eq 'User-Password' &&
		     $attr->{'UATTR_VALUE'} eq $vars->{'radpsswd'} ) {
			$logok = 1;
			my $ligne = ligne_par_id($ru->{'LIGNE_ID'});
			$cid = $ligne->{'CLIENT_ID'};
			goto GOOD;
		}
	}
	$logok = 0;
	info "Mot de passe radius ne correspond pas";
} else {
	my $login = $vars->{'adhlogin'};
	my $passwd = $vars->{'adhpasswd'};
	my $adh = adhaccess_par_login($login);
	if ( ! defined $adh ) {
		info "Identifiant adherent inconnu";
		goto BAD;
	}
	if ( $adh->{'ADHACCESS_PASSWD'} ne $passwd ) {
		info "Mot de passe invalide";
		goto BAD;
	}
	$logok = 1;
	$cid = $adh->{'CLIENT_ID'};
}

BAD:

if ( ! $logok ) {
	$page = affiche_form($form,$vars);
	$page .= $err;
	eject_page($page);
	exit(0);
}

GOOD:

my $sess = new_session('adh');
my $info = $vars->{'info'};
$sess->{content} = {
	'cid' => $cid,
	'info' => $info,
};
debug "Info: $info";
store_session($sess);
info "Connection ok. Session: ".$sess->{name};
print "Location: adh-in.cgi?sess=".$sess->{name}."\n\n";

